@@ -1,9 +1,14 @@
 from ...plugin import Plugin
 
 
+# NOTE:
+# Consider using pure jQuery instead of ue-scroll
+# Consider adding help button to teach how to scroll sidebars, shorcuts, etc
+
+
 class DisplayPlugin(Plugin):
-    name = "display"
-    profile = {
+    identity = "display"
+    validity = {
         "type": "object",
         "properties": {
             "speed": {"type": "integer"},
@@ -12,7 +17,7 @@ class DisplayPlugin(Plugin):
 
     # Context
 
-    @Plugin.property
+    @property
     def speed(self):
         return self.config.get("speed", 10)
 
